| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Description | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
This module contains the core functionality of the XML-RPC library. Most applications should not need to use this module. Client applications should use XmlRpcClient and server applications should use XmlRpcServer. The XML-RPC specifcation is available at http://www.xmlrpc.com/spec. | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Synopsis | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Method calls and repsonses | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| data MethodCall | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| data MethodResponse | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| XML-RPC types | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| data Value | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| data Type | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| class XmlRpcType a where | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Converting from XML | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| parseResponse :: Monad m => String -> Err m MethodResponse | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Parses a method response from XML. | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| parseCall :: Monad m => String -> Err m MethodCall | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Parses a method call from XML. | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| getField | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| getFieldMaybe | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Converting to XML | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| renderCall :: MethodCall -> String | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Makes an XML-representation of a method call. FIXME: pretty prints ugly XML | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| renderResponse :: MethodResponse -> String | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Makes an XML-representation of a method response. FIXME: pretty prints ugly XML | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Error monad | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| type Err m a = ErrorT String m a | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| maybeToM | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| handleError :: Monad m => (String -> m a) -> Err m a -> m a | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Handle errors from the error monad. | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| ioErrorToErr :: IO a -> Err IO a | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Catch IO errors in the error monad. | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
| Produced by Haddock version 0.8 | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||||